@@ -2,38 +2,78 @@ require 'feedparser'
 require 'feedparser/filesizes'
 
 module FeedParser
+  STYLESHEET = <<~EOF
+  <style type="text/css">
+  body {
+    margin: 2em auto;
+    max-width: 960px;
+  }
+
+  table.header {
+    margin-bottom: 1em;
+  }
+
+  table.header, table.metadata, table.attachments {
+    font-family: Helvetica, Verdana, sans-serif;
+  }
+
+  table.header, table.metadata, table.attachments, pre {
+    width: 100%;
+    padding: 0.5em;
+    background: #eeeeec;
+    border: 1px solid #babdb6;
+  }
+
+  table.header th, table.metadata th, table.attachments th {
+    text-align: right;
+    width: 50px;
+  }
+
+  blockquote {
+    font-style: italic;
+    color: #2e3436;
+    border-left: 2px solid #babdb6;
+    padding-left: 0.5em;
+  }
+
+  hr {
+    border: none;
+    border-top: 1px solid #babdb6;
+    margin: 1em auto
+  }
+  </style>
+  EOF
   class Feed
     def to_html(localtime = true)
       s = ''
-      s += '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">'
-      s += "\n"
-      s += "<html>\n"
+      s += "<!doctype html>\n"
+      s += "<html lang=en>\n"
       s += "<head>\n"
+      s += "<meta charset=\"utf-8\"/>\n"
       s += "<title>#{@title.escape_html}</title>\n"
-      s += "<meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\">\n"
+      s += FeedParser::STYLESHEET
       s += "</head>\n"
       s += "<body>\n"
 
       s += <<-EOF
-<table border="1" width="100%" cellpadding="0" cellspacing="0" borderspacing="0"><tr><td>
-<table width="100%" bgcolor="#EDEDED" cellpadding="4" cellspacing="2">
+<table class="feed-header">
       EOF
       r = ""
       r += "<a href=\"#{@link}\">\n" if @link
       if @title
-        r += "<b>#{@title.escape_html}</b>\n"
+        r += @title.escape_html
       elsif @link
-        r += "<b>#{@link.escape_html}</b>\n"
+        r += @link.escape_html
       else
-        r += "<b>Unnamed feed</b>\n"
+        r += "Unnamed feed"
       end
       r += "</a>\n" if @link
-      headline = "<tr><td align=\"right\"><b>%s</b></td>\n<td width=\"100%%\">%s</td></tr>"
+      headline = "<tr><th>%s</th>\n<td>%s</td></tr>"
       s += (headline % ["Feed title:", r])
       s += (headline % ["Type:", @type])
       s += (headline % ["Encoding:", @encoding])
       s += (headline % ["Creator:", @creator.escape_html]) if @creator
-      s += "</table></td></tr></table>\n"
+      s += "</table>\n"
 
       if @description and @description !~ /\A\s*</m
         s += "<br/>\n"
@@ -51,44 +91,47 @@ module FeedParser
 
   class FeedItem
     def to_html_with_headers(localtime = true)
-      s = <<-EOF
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
-<html>
-<body>
-  EOF
+      s = "<!doctype html>\n"
+      s += '<html lang="en">'
+      s += '<head>'
+      s += '<meta charset="utf-8"/>'
+      s += "<title>#{@title.escape_html}</title>\n"
+      s += FeedParser::STYLESHEET
+      s += '</head>'
+      s += '<body>'
       s += to_html(localtime)
-      s += "\n</body>\n</html>"
+      s += "</body>"
+      s += "</html>"
       s
     end
 
     def to_html(localtime = true)
       s = <<-EOF
-<table border="1" width="100%" cellpadding="0" cellspacing="0" borderspacing="0"><tr><td>
-<table width="100%" bgcolor="#EDEDED" cellpadding="4" cellspacing="2">
+<table class="header">
       EOF
       r = ""
       r += "<a href=\"#{@feed.link}\">\n" if @feed.link
       if @feed.title
-        r += "<b>#{@feed.title.escape_html}</b>\n"
+        r += @feed.title.escape_html
       elsif @feed.link
-        r += "<b>#{@feed.link.escape_html}</b>\n"
+        r += @feed.link.escape_html
       else
-        r += "<b>Unnamed feed</b>\n"
+        r += "Unnamed feed"
       end
       r += "</a>\n" if @feed.link
-      headline = "<tr><td align=\"right\"><b>%s</b></td>\n<td width=\"100%%\">%s</td></tr>"
+      headline = "<tr><th>%s</th>\n<td>%s</td></tr>"
       s += (headline % ["Feed:", r])
 
       r = ""
       r += "<a href=\"#{link}\">" if link
       if @title
-        r += "<b>#{@title.escape_html}</b>\n"
+        r += @title.escape_html
       elsif link
-        r += "<b>#{link.escape_html}</b>\n"
+        r += link.escape_html
       end
       r += "</a>\n" if link
       s += (headline % ["Item:", r])
-      s += "</table></td></tr></table>\n"
+      s += "</table>\n"
       s += "\n"
       if @content and @content !~ /\A\s*</m
         s += "<br/>\n"
@@ -96,19 +139,18 @@ module FeedParser
       s += "#{@content}" if @content
       if @enclosures and @enclosures.length > 0
         s += <<-EOF
-<table border="1" width="100%" cellpadding="0" cellspacing="0" borderspacing="0"><tr><td>
-<table width="100%" bgcolor="#EDEDED" cellpadding="2" cellspacing="2">
+<table class="attachments">
         EOF
-        s += '<tr><td width="100%"><b>Files:</b></td></tr>'
+        s += '<tr><th>Files:</th></tr>'
         s += "\n"
         @enclosures.each do |e|
-          s += "<tr><td>&nbsp;&nbsp;&nbsp;<a href=\"#{e[0]}\">#{e[0].split('/')[-1]}</a> (#{e[1].to_i.to_human_readable}, #{e[2]})</td></tr>\n"
+          s += "<tr><td><a href=\"#{e[0]}\">#{e[0].split('/')[-1]}</a> (#{e[1].to_i.to_human_readable}, #{e[2]})</td></tr>\n"
         end
-        s += "</table></td></tr></table>\n"
+        s += "</table>\n"
       end
-      s += "\n<hr width=\"100%\"/>\n"
-      s += '<table width="100%" cellpadding="0" cellspacing="0">' + "\n"
-      l = '<tr><td align="right"><font color="#ababab">%s</font>&nbsp;&nbsp;</td><td><font color="#ababab">%s</font></td></tr>' + "\n"
+      s += "\n<hr/>\n"
+      s += '<table class="metadata">' + "\n"
+      l = '<tr><th>%s</th><td>%s</td></tr>' + "\n"
       if @date
         if localtime
           s += l % [ 'Date:', @date.to_s ]
